@@ -9,7 +9,9 @@ from django.db.models.fields.files import FieldFile, FileField, ImageField
 from django.urls import reverse
 
 from ..conf import settings
-from .dynamic_storage import DynamicStorageFieldFile, DynamicStorageFileField, DynamicStorageImageField, DynamicStorageImageFieldFile, FileFieldMixin
+from .dynamic_storage import (DynamicStorageFieldFile, DynamicStorageFileField,
+                              DynamicStorageImageField,
+                              DynamicStorageImageFieldFile, FileFieldMixin)
 
 log = logging.getLogger(__name__)
 
@@ -25,14 +27,14 @@ class EncryptedFile(BytesIO):
 class DecryptedFile(BytesIO):
     def __init__(self, content, fernet):
         if content:
+            if isinstance(content, EncryptedFieldFile):
+                content = content.read()
             BytesIO.__init__(self, fernet.decrypt(content))
         else:
             BytesIO.__init__(self, None)
 
 
 class EncryptedFieldFile(DynamicStorageFieldFile):
-    """FieldFile which leverages the `dynamic_storages.fields.DynamicStorageFieldFile` ability to use a callable for the storage backend while also encrypting and decrypting the content to be stored on the fly"""
-
     def __init__(self, instance, field, name, **kwargs):
         self.fernet = getattr(field, "fernet", None)
         super().__init__(instance, field, name)
@@ -60,8 +62,7 @@ class EncryptedFieldFile(DynamicStorageFieldFile):
         return None
 
     def get_decrypted(self):
-        with self.open("rb") as f:
-            return DecryptedFile(f, self.fernet)
+        return DecryptedFile(self.open('rb').read(), self.fernet)
 
     url = property(_get_url)
 
@@ -78,8 +79,6 @@ class EncryptedFieldFile(DynamicStorageFieldFile):
 
 
 class EncryptedFileField(DynamicStorageFileField):
-    """FileField which leverages the `dynamic_storages.fields.DynamicStorageFileField` ability to use a callable for the storage backend while also encrypting and decrypting the content to be stored on the fly"""
-
     attr_class = EncryptedFieldFile
 
     def __init__(self, *args, **kwargs):
@@ -93,9 +92,7 @@ class EncryptedFileField(DynamicStorageFileField):
         return name, path, args, kwargs
 
 
-class EncryptedImageFieldFile(ImageFile, EncryptedImageFieldFile):
-    """ImageFieldFile which leverages the `dynamic_storages.fields.EncryptedImageFieldFile` ability to use a callable for the storage backend while also encrypting and decrypting the content to be stored on the fly"""
-
+class EncryptedImageFieldFile(ImageFile, EncryptedFieldFile):
     def delete(self, save=True):
         if hasattr(self, "_dimensions_cache"):
             del self._dimensions_cache
@@ -106,8 +103,6 @@ class EncryptedImageFieldFile(ImageFile, EncryptedImageFieldFile):
 
 
 class EncryptedImageField(DynamicStorageImageField):
-    """ImageFileField which leverages the `dynamic_storages.fields.DynamicStorageImageField` ability to use a callable for the storage backend while also encrypting and decrypting the content to be stored on the fly"""
-
     attr_class = EncryptedImageFieldFile
 
     def __init__(self, *args, **kwargs):
